@@ -28,6 +28,8 @@
 #include <QSet>
 #include <QString>
 
+using namespace Qt::Literals;
+
 void initEnvironment()
 {
     // We need the default locale to be English otherwise the brokenTags test fails
@@ -171,6 +173,10 @@ void KLocalizedStringTest::correctSubs()
     QCOMPARE(i18np("A pod left on %2", "Some pods left on %2", 1, QString("Discovery")), QString("A pod left on Discovery"));
     QCOMPARE(i18np("A pod left on %2", "Some pods left on %2", 2, QString("Discovery")), QString("Some pods left on Discovery"));
 
+    // No plural-number in singular or plural, but another argument present and plural decider not in %1.
+    QCOMPARE(i18np("Found one image in album %1", "Found some images in album %1", QString("AlbumName"), 1), QString("Found one image in album AlbumName"));
+    QCOMPARE(i18np("Found one image in album %1", "Found some images in album %1", QString("AlbumName"), 33), QString("Found some images in album AlbumName"));
+
     // Visual formatting.
     // FIXME: Needs much more tests.
     QCOMPARE(xi18n("E = mc^2"), QString("E = mc^2"));
@@ -301,12 +307,20 @@ void KLocalizedStringTest::semanticTags()
     // <numid/>
     QEXPECT_FAIL("", "what happened to <numid/>? TODO.", Continue);
     QCOMPARE(xi18nc("@info:progress", "Connecting to <numid>%1</numid>...", 22), QString("<html>Connecting to <tt>22</tt></html>"));
+    // <placeholder/>
     QCOMPARE(xi18nc("@info", "Replace <placeholder>name</placeholder> with your name."), QString("<html>Replace &lt;<i>name</i>&gt; with your name.</html>"));
     QCOMPARE(xi18nc("@item:inlistbox", "<placeholder>All images</placeholder>"), QString("<All images>"));
     // <resource/>
     QCOMPARE(xi18nc("@info", "Apply color scheme <resource>%1</resource>?", "XXX"), QString("<html>Apply color scheme “XXX”?</html>"));
+    // <shortcut/>
     QCOMPARE(xi18nc("@info:whatsthis", "Cycle through layouts using <shortcut>Alt+Space</shortcut>."),
              QString("<html>Cycle through layouts using <b>Alt+Space</b>.</html>"));
+    // shortcuts should allow for the usage of the delimiter as a key
+    QCOMPARE(xi18nc("@info", "Zoom in with <shortcut>Meta++</shortcut>."), QString("<html>Zoom in with <b>Meta++</b>.</html>"));
+    // '-' is used as a delimiter if seen before +, but replaced with '+'
+    QCOMPARE(xi18nc("@info", "Zoom out with <shortcut>Meta--</shortcut>."), QString("<html>Zoom out with <b>Meta+-</b>.</html>"));
+    // '-' as a delimiter with delimiter as key and also including '+'
+    QCOMPARE(xi18nc("@info", "Zoom out with <shortcut>Meta---+</shortcut>."), QString("<html>Zoom out with <b>Meta+-++</b>.</html>"));
     // <note/>
     QCOMPARE(xi18nc("@info",
                     "Probably the best known of all duck species is the Mallard. "
@@ -410,6 +424,25 @@ void KLocalizedStringTest::translateToFrench()
     }
     QCOMPARE(i18n("Loadable modules"), QString::fromUtf8("Modules chargeables"));
     QCOMPARE(i18n("Job"), QString::fromUtf8("Tâche"));
+    // These are pobably not correct French translations, apologies, we want to
+    // test that using %2 in the translation works
+    QCOMPARE(i18ncp("You can use %2 in the translation as number of images",
+                    "Found one image in album %1",
+                    "Found multiple images in album %1",
+                    QString("AlbumName"),
+                    1),
+             QString("Trouvé 1 image dans l'album AlbumName"));
+    QCOMPARE(i18ncp("You can use %2 in the translation as number of images",
+                    "Found one image in album %1",
+                    "Found multiple images in album %1",
+                    QString("AlbumName"),
+                    33),
+             QString("33 images trouvées dans l'album AlbumName"));
+    // These are pobably not correct French translations, apologies, we want to
+    // test that using not using the count number in the translation works
+    QCOMPARE(i18np("Found %2 image in album %1", "Found %2 images in album %1", QString("AlbumName"), 1), QString("Trouvé an image dans l'album AlbumName"));
+    QCOMPARE(i18np("Found %2 image in album %1", "Found %2 images in album %1", QString("AlbumName"), 33),
+             QString("Plusiers images trouvées dans l'album AlbumName"));
 }
 
 void KLocalizedStringTest::testLocalizedTranslator()
@@ -522,6 +555,24 @@ void KLocalizedStringTest::testLazy()
     KLocalizedString s = kli18n("Job");
     KLocalizedString::setLanguages({"fr"});
     QCOMPARE(s.toString(), QString::fromUtf8("Tâche"));
+    KLocalizedString::clearLanguages();
+}
+
+void KLocalizedStringTest::testLanguageChange()
+{
+    if (!m_hasFrench) {
+        QSKIP("French test files not usable.");
+    }
+
+    QCOMPARE(i18n("Job"), "Job"_L1);
+    const auto prevLangs = qgetenv("LANGUAGE");
+    qputenv("LANGUAGE", "fr_FR");
+    QCOMPARE(i18n("Job"), "Job"_L1);
+    QCoreApplication::sendEvent(QCoreApplication::instance(), new QEvent(QEvent::LanguageChange));
+    QCOMPARE(i18n("Job"), u"Tâche");
+    qputenv("LANGUAGE", prevLangs);
+    QCoreApplication::sendEvent(QCoreApplication::instance(), new QEvent(QEvent::LanguageChange));
+    QCOMPARE(i18n("Job"), "Job"_L1);
 }
 
 QTEST_MAIN(KLocalizedStringTest)
